/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "StyleSheetList.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomStyleSheet.h"
#include "gdom/GdomStyleSheetList.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomStyleSheet.h"
#include "gdom/PrivateGdomStyleSheetList.h"
#include "gdom/PrivateIntGdomStyleSheet.h"
#include "gdom/PrivateIntGdomStyleSheetList.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::StyleSheetList* obj)
{
    return WebCore::cacheDOMObject<WebCore::StyleSheetList, GDOMStyleSheetList>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMStyleSheetList::GDOMStyleSheetList(PassRefPtr<WebCore::StyleSheetList> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMStyleSheetList::~GDOMStyleSheetList()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

GdomStyleSheet *
gdom_style_sheet_list_item (GdomStyleSheetList *thiz, gulong index)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::StyleSheetList * item = (gdom_style_sheet_list_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::StyleSheet> g_res = WTF::getPtr(item->item(index));
    GdomStyleSheet * res = static_cast<GdomStyleSheet *>(WebCore::toGDOM(g_res.get()));
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "StyleSheetList.h"
#include <gdom/GdomStyleSheetList.h>
#include <gdom/PrivateGdomStyleSheetList.h>
#include <gdom/PrivateIntGdomStyleSheetList.h>
#include <gdom/GdomStyleSheetListprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomStyleSheetList, gdom_style_sheet_list, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomStyleSheetListPrivate {
    class WebCore::StyleSheetList *item;
};

#define GDOM_STYLE_SHEET_LIST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_STYLE_SHEET_LIST, GdomStyleSheetListPrivate))
*/
G_END_DECLS
WebCore::StyleSheetList *
gdom_style_sheet_list_get_private(GdomStyleSheetList *request)
{
    GDOMStyleSheetList *res;
    res = static_cast<GDOMStyleSheetList*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::StyleSheetList*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_LENGTH,
};


static void gdom_style_sheet_list_finalize(GObject* object)
{
    /*GdomStyleSheetList* request = GDOM_STYLE_SHEET_LIST(object);*/
    /*GdomStyleSheetListPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_style_sheet_list_parent_class)->finalize(object);
}

static void gdom_style_sheet_list__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomStyleSheetList *self = GDOM_STYLE_SHEET_LIST(object);
    WebCore::StyleSheetList * gself = (gdom_style_sheet_list_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_style_sheet_list__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomStyleSheetList *self = GDOM_STYLE_SHEET_LIST(object);
    WebCore::StyleSheetList * gself = (gdom_style_sheet_list_get_private(self));
    switch (prop_id) {
    case PROP_LENGTH:
    {
         g_value_set_ulong (value, gself->length());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_style_sheet_list_class_init(GdomStyleSheetListClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_style_sheet_list_finalize;
    g_klass->set_property = gdom_style_sheet_list__set_property_fn;
    g_klass->get_property = gdom_style_sheet_list__get_property_fn;

    g_object_class_install_property (g_klass, PROP_LENGTH,
            g_param_spec_ulong ("length", /* name */
                "style_sheet_list_length", /* short description */
                "read-only  gulong StyleSheetList.length", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomStyleSheetListPrivate));*/
}

static void gdom_style_sheet_list_init(GdomStyleSheetList* request)
{
    /*GdomStyleSheetListPrivate* priv = GDOM_STYLE_SHEET_LIST_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

